@@ -381,8 +381,14 @@ Perl_scan_version(pTHX_ const char *s, SV *rv, bool qv)
 		s = last;
 		break;
 	    }
-	    else if ( *pos == '.' )
-		s = ++pos;
+	    else if ( *pos == '.' ) {
+		pos++;
+		if (qv) {
+		    while (*pos == '0')
+			++pos;
+		}
+		s = pos;
+	    }
 	    else if ( *pos == '_' && isDIGIT(pos[1]) )
 		s = ++pos;
 	    else if ( *pos == ',' && isDIGIT(pos[1]) )
@@ -833,6 +839,11 @@ Perl_vnumify(pTHX_ SV *vs)
     }
 
 
+    if (alpha) {
+	Perl_ck_warner(aTHX_ packWARN(WARN_NUMERIC),
+		       "alpha->numify() is lossy");
+    }
+
     /* attempt to retrieve the version array */
     if ( !(av = MUTABLE_AV(SvRV(*hv_fetchs(MUTABLE_HV(vs), "version", FALSE))) ) ) {
 	return newSVpvs("0");
@@ -918,8 +929,6 @@ Perl_vnormal(pTHX_ SV *vs)
 	alpha = TRUE;
     if ( hv_exists(MUTABLE_HV(vs), "qv", 2) )
 	qv = TRUE;
-    if (alpha && ! qv)
-	Perl_croak(aTHX_ "Invalid version method call");
 
     av = MUTABLE_AV(SvRV(*hv_fetchs(MUTABLE_HV(vs), "version", FALSE)));
 
